#!/bin/bash

USER_ID=${LOCAL_USER_ID:-9001}

# This muddies results when we get output of a container run. Uncomment for debugging!
# echo "Starting with UID: $USER_ID"
useradd --shell /bin/bash -u $USER_ID -o -c "" -m giguser
export HOME=/home/giguser

# Setup /mnt/ as a safe place to put user runnable code
mkdir /mnt/labbook
chown -R giguser:root /mnt/labbook

# Setup docker sock to run as the user
chown giguser:root /run/docker.sock
chmod 777 /var/run/docker.sock

export JUPYTER_RUNTIME_DIR=/mnt/share/jupyter/runtime
chown -R giguser:root /mnt/share/

if [ -n "$XDG_CACHE_HOME" ]; then
    mkdir -p $XDG_CACHE_HOME
    # Even though (last I checked) this is in /mnt/labbook, it might change, so we handle it directly
    chown -R giguser:root $XDG_CACHE_HOME
fi

# If user information is available via env vars, pre-configure git client
if [ -n "$GIGANTUM_EMAIL" ]; then 
  gosu giguser git config --global user.email "$GIGANTUM_EMAIL"
  gosu giguser git config --global user.name "$GIGANTUM_USERNAME" 
  # We make store the default so it's easier to simply add a .git-credentials file via secrets
  gosu giguser git config --global credential.helper store
  if hash git-lfs 2>/dev/null; then
      gosu giguser git-lfs install
  fi
fi

# Run the Docker Command
exec gosu giguser "$@"
